@@ -14,13 +14,14 @@ CFX_FontCache::CFX_FontCache() = default;
 
 CFX_FontCache::~CFX_FontCache() = default;
 
-RetainPtr<CFX_GlyphCache> CFX_FontCache::GetGlyphCache(const CFX_Font* pFont) {
-  RetainPtr<CFX_Face> face = pFont->GetFace();
+RetainPtr<CFX_GlyphCache> CFX_FontCache::GetGlyphCache(const CFX_Font* font) {
+  RetainPtr<CFX_Face> face = font->GetFace();
   const bool bExternal = !face;
-  auto& map = bExternal ? m_ExtGlyphCacheMap : m_GlyphCacheMap;
+  auto& map = bExternal ? ext_glyph_cache_map_ : glyph_cache_map_;
   auto it = map.find(face.Get());
-  if (it != map.end() && it->second)
+  if (it != map.end() && it->second) {
     return pdfium::WrapRetain(it->second.Get());
+  }
 
   auto new_cache = pdfium::MakeRetain<CFX_GlyphCache>(face);
   map[face.Get()].Reset(new_cache.Get());
@@ -28,7 +29,7 @@ RetainPtr<CFX_GlyphCache> CFX_FontCache::GetGlyphCache(const CFX_Font* pFont) {
 }
 
 #if defined(PDF_USE_SKIA)
-CFX_TypeFace* CFX_FontCache::GetDeviceCache(const CFX_Font* pFont) {
-  return GetGlyphCache(pFont)->GetDeviceCache(pFont);
+CFX_TypeFace* CFX_FontCache::GetDeviceCache(const CFX_Font* font) {
+  return GetGlyphCache(font)->GetDeviceCache(font);
 }
 #endif
